@@ -209,6 +209,15 @@ require "stringio"
           expect(File.exist?(old_path)).to eq false
         end
 
+        it "deletes *.cache files generated from .mpc" do
+          image = described_class.open(image_path)
+          image.format("mpc")
+          cache_path = image.path.sub(/mpc$/, "cache")
+          image.format("png")
+
+          expect(File.exists?(cache_path)).to eq false
+        end
+
         it "doesn't delete itself when formatted to the same format" do
           subject.format(subject.type.downcase)
           expect(File.exists?(subject.path)).to eq true
@@ -231,6 +240,7 @@ require "stringio"
           layer = subject.layers.first
           layer.format('jpg')
           expect(layer).to be_valid
+          expect(layer.path[/\..+$/]).to eq ".jpg"
           expect(File.exist?(layer.path)).to eq true
         end
 
@@ -541,6 +551,30 @@ require "stringio"
         end
       end
 
+      describe "#destroy!" do
+        it "deletes the underlying tempfile" do
+          image = described_class.open(image_path)
+          image.destroy!
+
+          expect(File.exists?(image.path)).to eq false
+        end
+
+        it "doesn't delete when there is no tempfile" do
+          image = described_class.new(image_path)
+          image.destroy!
+
+          expect(File.exists?(image.path)).to eq true
+        end
+
+        it "deletes .cache files generated by handling .mpc files" do
+          image = described_class.open(image_path)
+          image.format("mpc")
+          image.destroy!
+
+          expect(File.exists?(image.path.sub(/mpc$/, "cache"))).to eq false
+        end
+      end
+
       describe "#identify" do
         it "returns the output of identify" do
           expect(subject.identify).to match(subject.type)
