@@ -9,10 +9,10 @@ RSpec.describe MiniMagick::Shell do
       subject.run(%W[identify #{image_path}])
     end
 
-    it "returns stdout" do
+    it "returns stdout, stderr and status" do
       allow(subject).to receive(:execute).and_return(["stdout", "stderr", 0])
       output = subject.run(%W[foo])
-      expect(output).to eq "stdout"
+      expect(output).to eq ["stdout", "stderr", 0]
     end
 
     it "uses stderr for error messages" do
@@ -29,7 +29,7 @@ RSpec.describe MiniMagick::Shell do
 
     it "raises errors only in whiny mode" do
       allow(subject).to receive(:execute).and_return(["stdout", "", 127])
-      expect(subject.run(%W[foo], whiny: false)).to eq "stdout"
+      expect { subject.run(%W[foo], whiny: false) }.not_to raise_error
     end
 
     it "prints to stderr output to $stderr in non-whiny mode" do
@@ -61,9 +61,11 @@ RSpec.describe MiniMagick::Shell do
         end
 
         it "logs the command and execution time in debug mode" do
-          allow(MiniMagick).to receive(:debug).and_return(true)
-          expect { subject.execute(%W[identify #{image_path(:gif)}]) }.
-            to output(/\[\d+.\d+s\] identify #{image_path(:gif)}/).to_stdout
+          MiniMagick.logger = Logger.new(stream = StringIO.new)
+          MiniMagick.logger.level = Logger::DEBUG
+          subject.execute(%W[identify #{image_path(:gif)}])
+          stream.rewind
+          expect(stream.read).to match /\[\d+.\d+s\] identify #{image_path(:gif)}/
         end
 
         it "doesn't break on spaces" do
